@@ -1,4 +1,3 @@
-
 """
 This is a toplevel package of Apiritif tool
 Copyright 2017 BlazeMeter Inc.
@@ -14,11 +13,9 @@ limitations under the License.
 """
 
 from .csv import CSVReaderPerThread
-from .thread import put_into_thread_store, get_from_thread_store, external_handler
+from .thread import put_into_thread_store, get_from_thread_store, external_handler, get_stage, set_stage
 from .thread import get_transaction_handlers, set_transaction_handlers, get_iteration
 from .http import http, transaction, transaction_logged, smart_transaction, recorder
 from .http import Event, TransactionStarted, TransactionEnded, Request, Assertion, AssertionFailure
 from .utilities import *
 from .utils import headers_as_text, assert_regexp, assert_not_regexp, log
-# DEPRECATED
-from .thread import get_logging_handlers, set_logging_handlers, external_log
